# Lapidary render

[![.github/workflows/test.yml](https://github.com/python-lapidary/lapidary-render/actions/workflows/test.yml/badge.svg)](https://github.com/python-lapidary/lapidary-render/actions/workflows/test.yml)

Lapidary-render is a program that generates Python Web API clients from OpenAPI documents.
